@@ -12,12 +12,17 @@ import numpy as np
 # DLL_EXPORT void matchsig_2(const emxArray_real_T *ref, const emxArray_real_T *sig, double
 #                 fs, double type,emxArray_real_T *sig_out, double *delay, double *err)
 
-def match_sig(refFile=None,targetFile=None,outFile=None):
+
+# void matchsig_2(const emxArray_real_T *ref, const emxArray_real_T *sig, double
+#                 fs, double type, emxArray_real_T *sig_out, double *delay, double
+#                 *err)
+
+def match_sig(refFile=None,testFile=None,outFile=None,audioType=1):
     """
     """
 
     refstruct, refsamplerate,reflen = get_data_of_ctypes_(refFile)
-    teststruct, testsamplerate,testlen = get_data_of_ctypes_(targetFile)
+    teststruct, testsamplerate,testlen = get_data_of_ctypes_(testFile)
     outlen = max(reflen,testlen)
     data =  np.array([0.0 for _ in range(outlen)])
     data = data.astype(np.float64)
@@ -36,7 +41,7 @@ def match_sig(refFile=None,targetFile=None,outFile=None):
     mydll.matchsig_2.argtypes = [POINTER(emxArray_real_T), POINTER(emxArray_real_T), POINTER(emxArray_real_T),c_double,c_double,
                                      POINTER(c_double), POINTER(c_double)]
     delay, err = c_double(0.0), c_double(0.0)
-    mydll.matchsig_2(byref(refstruct), byref(teststruct), byref(outStruct),c_double(refsamplerate),c_double(1),byref(delay), byref(err))
+    mydll.matchsig_2(byref(refstruct), byref(teststruct), byref(outStruct),c_double(refsamplerate),c_double(audioType),byref(delay), byref(err))
     if err.value > 0.0:
         return None
     else:
