@@ -25,8 +25,9 @@ from SNR_ESTIMATION.SNR_TRANSIENT import cal_snr_transient
 from AGC_EVALUATION.CAL_GAIN_TABLE import cal_gain_table
 from AGC_EVALUATION.CAL_ATTACK_RELEASE import cal_attack_release
 from AGC_EVALUATION.CAL_MUSIC_STABILITY import cal_music_stablility
+from AGC_EVALUATION.CAL_DELAY import cal_DELAY
 
-allMetrics = ['G160','P563','POLQA','PESQ','STOI','STI','PEAQ','SDR','SII','LOUDNESS','MUSIC','TRANSIENT','MATCH','GAINTABLE','ATTACKRELEASE','MUSICSTA']
+allMetrics = ['G160','P563','POLQA','PESQ','STOI','STI','PEAQ','SDR','SII','LOUDNESS','MUSIC','TRANSIENT','MATCH','GAINTABLE','ATTACKRELEASE','MUSICSTA','AGCDELAY']
 
 
 class computeAudioQuality():
@@ -57,7 +58,7 @@ class computeAudioQuality():
         self.testOffset = kwargs['refOffset']
         self.maxComNLevel = kwargs['maxComNLevel']
         self.speechPauseLevel = kwargs['speechPauseLevel']
-        self.gaintableType = kwargs["gaintableType"]
+        self.audioType = kwargs["audioType"]
         #maxComNLevel=c_double(-48.0),speechPauseLevel=c_double(-35.0)
 
     def __chcek_valid(self):
@@ -260,7 +261,7 @@ class computeAudioQuality():
         :return:
         """
         self.__double_end_check()
-        return match_sig(pcm2wav(self.refFile,sample_rate=self.samplerate), pcm2wav(self.testFile,sample_rate=self.samplerate), self.outFile)
+        return match_sig(pcm2wav(self.refFile,sample_rate=self.samplerate), pcm2wav(self.testFile,sample_rate=self.samplerate), self.outFile,self.audioType)
 
     def LOUDNESS(self):
         pass
@@ -277,7 +278,7 @@ class computeAudioQuality():
         """
         self.__double_end_check()
         return cal_gain_table(refFile=pcm2wav(self.refFile, sample_rate=self.samplerate),
-                             testFile=pcm2wav(self.testFile, sample_rate=self.samplerate),targetType=self.gaintableType)
+                             testFile=pcm2wav(self.testFile, sample_rate=self.samplerate),targetType=self.audioType)
 
     def ATTACKRELEASE(self):
         """
@@ -296,4 +297,14 @@ class computeAudioQuality():
         """
         self.__double_end_check()
         return cal_music_stablility(refFile=pcm2wav(self.refFile, sample_rate=self.samplerate),
+                             testFile=pcm2wav(self.testFile, sample_rate=self.samplerate))
+
+    def AGCDELAY(self):
+        """
+        AGC PARA 3
+        计算文件延时
+        :return:
+        """
+        self.__double_end_check()
+        return cal_DELAY(refFile=pcm2wav(self.refFile, sample_rate=self.samplerate),
                              testFile=pcm2wav(self.testFile, sample_rate=self.samplerate))
\ No newline at end of file
