@@ -5,9 +5,9 @@ from ctypes import  *
 
 def compute_audio_quality(metrics, testFile=None, refFile=None, cleFile=None, outFile=None, noiseFile=None,
                               samplerate=16000, bitwidth=2, channel=1, refOffset=0, testOffset=0, maxComNLevel=-48.0,
-                              speechPauseLevel=-35.0,gaintableType=0):
+                              speechPauseLevel=-35.0,audioType=0):
     """
-    :param metrics: G160/P563/POLQA/PESQ/STOI/STI/PEAQ/SDR/SII/LOUDNESS/MUSIC/MATCH/TRANSIENT/GAINTABLE/ATTACKRELEASE/MUSICSTA，必选项
+    :param metrics: G160/P563/POLQA/PESQ/STOI/STI/PEAQ/SDR/SII/LOUDNESS/MUSIC/MATCH/TRANSIENT/GAINTABLE/ATTACKRELEASE/MUSICSTA/AGCDELAY，必选项
     # G160 无采样率限制；  WAV/PCM输入 ；三端输入: clean、ref、test；无时间长度要求；
     # 计算 信噪比提升、短时降噪、长时降噪、语音损伤等指标
     # P563 8000hz(其他采样率会强制转换到8khz)；  WAV/PCM输入 ；单端输入: test；时长 < 20s；
@@ -35,6 +35,8 @@ def compute_audio_quality(metrics, testFile=None, refFile=None, cleFile=None, ou
     # 计算AGC attack 和release 的时间
     # MUSICSTA 无采样率限制,WAV/PCM输入;双端输入：ref、test；无时间长度要求；
     # 音乐信号的稳定性
+    # AGCDELAY 无采样率限制,WAV/PCM输入;双端输入：ref、test；无时间长度要求；
+    # 用于测试AGC文件的对齐
     不同指标输入有不同的采样率要求，如果传入的文件不符合该指标的要求，会自动变采样到合法的区间
     :param testFile: 被测文件，必选项
     :param refFile:  参考文件，可选项，全参考指标必选，比如POLQA/PESQ/PEAQ
@@ -46,6 +48,9 @@ def compute_audio_quality(metrics, testFile=None, refFile=None, cleFile=None, ou
     :param channel: 通道数，可选项，pcm文件需要 default = 1
     :param refOffset: ref文件的样点偏移，可选项，指标G160需要
     :param testOffset: test文件的样点偏移，可选项，指标G160需要
+    :param maxComNLevel: 测试G160文件的最大舒适噪声
+    :param speechPauseLevel 测试G160文件的语音间歇段的噪声
+    :param gaintableType 测试gaintable的模式 0：语音 1：音乐
     :return:
     """
     paraDicts = {
@@ -62,7 +67,7 @@ def compute_audio_quality(metrics, testFile=None, refFile=None, cleFile=None, ou
         'testOffset':testOffset,
         'maxComNLevel':maxComNLevel,
         "speechPauseLevel":speechPauseLevel,
-        'gaintableType':gaintableType
+        'audioType':audioType
     }
     comAuQUA = computeAudioQuality(**paraDicts)
     return methodcaller(metrics)(comAuQUA)
@@ -92,7 +97,7 @@ if __name__ == '__main__':
 
     file = r'C:\Users\vcloud_avl\Downloads\agc_eva\speech_gaintable.wav'
     test = r'C:\Users\vcloud_avl\Downloads\agc_eva\test.wav'
-    lim,gain_table,DR = compute_audio_quality('GAINTABLE',refFile=file,testFile=test,gaintableType=1)
+    lim,gain_table,DR = compute_audio_quality('GAINTABLE',refFile=file,testFile=test,audioType=1)
     print(lim,gain_table[0],DR[2])
     for a in gain_table:
         print(a)
@@ -105,4 +110,9 @@ if __name__ == '__main__':
     for a in res:
         print(a)
 
-    pass
\ No newline at end of file
+    file = r'C:\Users\vcloud_avl\Downloads\agc_eva\speech_gaintable.wav'
+    test = r'C:\Users\vcloud_avl\Downloads\agc_eva\test.wav'
+    delay = compute_audio_quality('AGCDELAY',refFile=file,testFile=test)
+    print(delay)
+
+    compute_audio_quality('MATCH',refFile=file,testFile=test,outFile='out.wav',audioType=1)
\ No newline at end of file
